Module: SolidStackWeb

Defined in:
lib/solid_stack_web.rb,
lib/solid_stack_web/engine.rb,
lib/solid_stack_web/version.rb,
app/models/solid_stack_web/job.rb,
app/models/solid_stack_web/cable_stats.rb,
app/models/solid_stack_web/cache_stats.rb,
app/models/solid_stack_web/queue_stats.rb,
app/models/solid_stack_web/alert_webhook.rb,
app/models/solid_stack_web/cable_timeline.rb,
app/models/solid_stack_web/cache_timeline.rb,
app/models/solid_stack_web/cache_size_stats.rb,
app/helpers/solid_stack_web/application_helper.rb,
app/controllers/solid_stack_web/jobs_controller.rb,
app/models/solid_stack_web/throughput_sparkline.rb,
app/controllers/solid_stack_web/cable_controller.rb,
app/controllers/solid_stack_web/cache_controller.rb,
app/controllers/solid_stack_web/stats_controller.rb,
app/models/solid_stack_web/queue_depth_sparkline.rb,
app/controllers/solid_stack_web/queues_controller.rb,
app/controllers/solid_stack_web/history_controller.rb,
app/controllers/solid_stack_web/metrics_controller.rb,
app/controllers/solid_stack_web/dashboard_controller.rb,
app/controllers/solid_stack_web/processes_controller.rb,
app/controllers/solid_stack_web/application_controller.rb,
app/controllers/solid_stack_web/failed_jobs_controller.rb,
app/controllers/solid_stack_web/cable/purges_controller.rb,
app/controllers/solid_stack_web/cache/flushes_controller.rb,
app/controllers/solid_stack_web/cache_entries_controller.rb,
app/controllers/solid_stack_web/queues/pauses_controller.rb,
lib/generators/solid_stack_web/install/install_generator.rb,
app/controllers/solid_stack_web/cable_messages_controller.rb,
app/controllers/solid_stack_web/scheduled_jobs_controller.rb,
app/controllers/solid_stack_web/jobs/selections_controller.rb,
app/controllers/solid_stack_web/recurring_tasks_controller.rb,
app/controllers/solid_stack_web/cable/channel_purges_controller.rb,
app/controllers/solid_stack_web/recurring_tasks/runs_controller.rb,
app/controllers/solid_stack_web/failed_jobs/arguments_controller.rb,
app/controllers/solid_stack_web/failed_jobs/selections_controller.rb

Defined Under Namespace

Modules: ApplicationHelper, FailedJobs, Generators, Jobs Classes: AlertWebhook, ApplicationController, CableController, CableMessagesController, CableStats, CableTimeline, CacheController, CacheEntriesController, CacheSizeStats, CacheStats, CacheTimeline, DashboardController, Engine, FailedJobsController, HistoryController, Job, JobsController, MetricsController, ProcessesController, QueueDepthSparkline, QueueStats, QueuesController, RecurringTasksController, ScheduledJobsController, StatsController, ThroughputSparkline

Constant Summary collapse

VERSION =
"0.9.0"

Class Attribute Summary collapse

Class Method Summary collapse

Class Attribute Details

.alert_failure_thresholdObject



32
33
34
# File 'lib/solid_stack_web.rb', line 32

def alert_failure_threshold
  @alert_failure_threshold
end

.alert_queue_thresholdsObject



36
37
38
# File 'lib/solid_stack_web.rb', line 36

def alert_queue_thresholds
  @alert_queue_thresholds || {}
end

.alert_webhook_cooldownObject



28
29
30
# File 'lib/solid_stack_web.rb', line 28

def alert_webhook_cooldown
  @alert_webhook_cooldown || 3600
end

.alert_webhook_urlObject



24
25
26
# File 'lib/solid_stack_web.rb', line 24

def alert_webhook_url
  @alert_webhook_url
end

.allow_value_previewObject



52
53
54
# File 'lib/solid_stack_web.rb', line 52

def allow_value_preview
  @allow_value_preview || false
end

.connects_toObject



16
17
18
# File 'lib/solid_stack_web.rb', line 16

def connects_to
  @connects_to
end

.dashboard_refresh_intervalObject



40
41
42
# File 'lib/solid_stack_web.rb', line 40

def dashboard_refresh_interval
  @dashboard_refresh_interval || 5_000
end

.default_refresh_intervalObject



44
45
46
# File 'lib/solid_stack_web.rb', line 44

def default_refresh_interval
  @default_refresh_interval || 10_000
end

.page_sizeObject



12
13
14
# File 'lib/solid_stack_web.rb', line 12

def page_size
  @page_size || 25
end

.search_results_limitObject



48
49
50
# File 'lib/solid_stack_web.rb', line 48

def search_results_limit
  @search_results_limit || 25
end

.slow_job_thresholdObject



20
21
22
# File 'lib/solid_stack_web.rb', line 20

def slow_job_threshold
  @slow_job_threshold
end

Class Method Details

.authenticate(&block) ⇒ Object



73
74
75
76
# File 'lib/solid_stack_web.rb', line 73

def authenticate(&block)
  @authenticate = block if block_given?
  @authenticate
end

.configure {|_self| ... } ⇒ Object

Yields:

  • (_self)

Yield Parameters:

  • _self (SolidStackWeb)

    the object that the method was called on



69
70
71
# File 'lib/solid_stack_web.rb', line 69

def configure
  yield self
end

.mount_pathObject

Returns the path at which the engine is mounted in the host application, derived automatically from the host’s routes. Host apps can use this to build links to the dashboard without hardcoding the mount path.

link_to "Dashboard", SolidStackWeb.mount_path


62
63
64
65
66
67
# File 'lib/solid_stack_web.rb', line 62

def mount_path
  route = Rails.application.routes.routes.find do |r|
    r.app.respond_to?(:app) && r.app.app == SolidStackWeb::Engine
  end
  route&.path&.spec&.to_s&.sub(%r{\(.*\)\z}, "") || "/"
end